@@ -251,9 +251,6 @@ class DeltaTable:
         create_table_query_str += " )"
         upsert_sql_str += f"{merge_update_set_str} WHEN NOT MATCHED THEN INSERT ({merge_insert_str}) VALUES ({merge_insert_values_str})"
 
-        # print(f"create_table_query_str: {create_table_query_str}")
-        # print(f"upsert_sql_str: {upsert_sql_str}")
-
         return {
             'struct_field_list': struct_field_list,
             'create_table_query_str': create_table_query_str,
@@ -270,7 +267,7 @@ class DeltaTable:
         """
         delete the delta table
         """
-#         dbutils.fs.rm(f"/delta/{self.schema_name}/{self.table_name}", recurse=True)
+        dbutils.fs.rm(f"/delta/{self.schema_name}/{self.table_name}", recurse=True)
         dbutils.fs.rm(self.checkpoint_base_path, recurse=True)
 
     def read_stream(self, spark: SparkSession, **kw):
@@ -306,7 +303,7 @@ class DeltaTable:
             .start()
 
 
-    def stream(self, spark: SparkSession) -> None:
+    def stream(self, spark: SparkSession, **kw) -> None:
         """
         stream data from s3 to a delta table
 
@@ -324,7 +321,7 @@ class DeltaTable:
         logger.info(str(log_msg))
         log_msg.clear()
 
-        df = self.read_stream(spark)
+        df = self.read_stream(spark, **kw)
 
         print(df.printSchema())
 
